@@ -191,6 +191,27 @@ def svn_txdelta_window_dup(*args):
     """svn_txdelta_window_dup(svn_txdelta_window_t window, apr_pool_t pool) -> svn_txdelta_window_t"""
     return apply(_delta.svn_txdelta_window_dup, args)
 
+def svn_txdelta_compose_windows(*args):
+    """
+    svn_txdelta_compose_windows(svn_txdelta_window_t window_A, svn_txdelta_window_t window_B, 
+        apr_pool_t pool) -> svn_txdelta_window_t
+    """
+    return apply(_delta.svn_txdelta_compose_windows, args)
+
+def svn_txdelta_apply_instructions(*args):
+    """
+    svn_txdelta_apply_instructions(svn_txdelta_window_t window, char sbuf, char tbuf, 
+        apr_size_t tlen)
+    """
+    return apply(_delta.svn_txdelta_apply_instructions, args)
+
+def svn_txdelta_stream_create(*args):
+    """
+    svn_txdelta_stream_create(void baton, svn_txdelta_next_window_fn_t next_window, 
+        svn_txdelta_md5_digest_fn_t md5_digest, apr_pool_t pool) -> svn_txdelta_stream_t
+    """
+    return apply(_delta.svn_txdelta_stream_create, args)
+
 def svn_txdelta_next_window(*args):
     """
     svn_txdelta_next_window(svn_txdelta_window_t window, svn_txdelta_stream_t stream, 
@@ -247,6 +268,14 @@ def svn_txdelta_apply(*args):
     """
     return apply(_delta.svn_txdelta_apply, args)
 
+def svn_txdelta_to_svndiff2(*args):
+    """
+    svn_txdelta_to_svndiff2(svn_txdelta_window_handler_t handler, void handler_baton, 
+        svn_stream_t output, int svndiff_version, 
+        apr_pool_t pool)
+    """
+    return apply(_delta.svn_txdelta_to_svndiff2, args)
+
 def svn_txdelta_to_svndiff(*args):
     """
     svn_txdelta_to_svndiff(svn_stream_t output, apr_pool_t pool, svn_txdelta_window_handler_t handler, 
